| B1_Meteo-class | R Documentation |
A class for meteorological data.
Objects can be created by the family of readBDd functions.
latm:Latitude (degrees) of the meteorological station or source of the data.
data:A data.table object with the time series of
daily irradiation (G0, Wh/m²), the ambient temperature (Ta)
or the maximum and minimum ambient
temperature (TempMax and TempMin).
source:A character with a short description of the source of the data.
type:A character, prom, bd or
bdI depending on the constructor.
signature(object = "Meteo"): extracts the
data slot as a data.table object.
signature(object = "Meteo"): extracts the
irradiation as vector.
signature(object = "Meteo"): extracts the
latitude value.
signature(object = "Meteo"): extracts the index
of the data slot.
signature(x = "formula", data = "Meteo"): plot
the content of the object according to the formula argument.
signature(x = "Meteo", data = "missing"): plot
the data slot using the xyplot method for zoo
objects.
Oscar Perpiñán Lamigueiro, Francisco Delgado López.
readBDd,
readBDi,
zoo2Meteo,
dt2Meteo,
readG0dm,
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.