| E_SIAR | R Documentation |
Information about the location and operational status of the stations that make up the SIAR network
data(SIAR)
est_SIAR is a data.table with 625 estations containing the following information:
Estacioncharacter, name of the station.
Codigocharacter, code of the station.
Longitudnumeric, longitude of the station in degrees (negative is for locations in the west).
Latitudnumeric, latitud of the station in degrees.
Altitudinteger, altitude of the station in meters.
Fecha_InstalacionDate, day the station was installed, and therefore, the start of its records.
Fecha_BajaDate, day the station was decommisioned,
and therefore, the end of its records (if its value is NA,
it means it is still operational).
https://servicio.mapa.gob.es/websiar/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.