| C_local2Solar | R Documentation |
The function local2Solar converts the time zone of a POSIXct object to
the mean solar time and set its time zone to UTC as a synonym of mean
solar time. It includes two corrections:
the difference of longitudes between the location and the time zone, and
the daylight saving time.
The function lonHH calculates the longitude (radians) of a time zone.
local2Solar(x, lon = NULL)
lonHH(tz)
x |
a |
lon |
A numeric value of the longitude (degrees) of the
location. If |
tz |
A character, a time zone as documented in https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. |
Since the result of local2Solar is the mean solar time, the
Equation of Time correction is not calculated with this function. The
eot function includes this correction if desired.
The function local2Solar produces a POSIXct object
with its time zone set to UTC.
The function lonHH gives a numeric value.
It is important to note that the solaR2 package sets the system
time zone to UTC with Sys.setenv(TZ = 'UTC').
Oscar Perpiñán Lamigueiro, Francisco Delgado López.
Perpiñán, O, Energía Solar Fotovoltaica, 2015. (https://oscarperpinan.github.io/esf/)
Perpiñán, O. (2012), "solaR: Solar Radiation and Photovoltaic Systems with R", Journal of Statistical Software, 50(9), 1-32, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v050.i09")}
library("data.table")
t.local <- as.POSIXct("2006-01-08 10:07:52", tz = 'Europe/Madrid')
##The local time zone and the location have the same longitude (15 degrees)
local2Solar(t.local)
##But Madrid is at lon = -3
local2Solar(t.local, lon = -3)
##Daylight saving time
t.local.dst <- as.POSIXct("2006-07-08 10:07:52", tz = 'Europe/Madrid')
local2Solar(t.local.dst)
local2Solar(t.local.dst, lon = -3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.